@@ -413,7 +413,9 @@ def bootstrap_cloud_minion(options):
         script_args.append('-I')
     if options.bootstrap_salt_url != SALT_GIT_URL:
         script_args.extend(['-g', options.bootstrap_salt_url])
-    if options.bootstrap_salt_commit:
+    if options.bootstrap_stable_install:
+        script_args.extend(['stable', options.bootstrap_stable_install])
+    if options.bootstrap_salt_commit and not options.bootstrap_stable_install:
         script_args.extend(['git', options.bootstrap_salt_commit])
 
     cmd = ['salt-cloud',
@@ -445,14 +447,19 @@ def bootstrap_cloud_minion(options):
         start = 0
         for line in s_ret:
             start += 1
-            if options.vm_name in line:
+            if line.startswith(options.vm_name):
                 break
 
         clean_stdout = '\n'.join(s_ret[start:]).replace('  ', '')
         try:
             # Failing on OpenNebula because public_ips returns []
-            print('IP', yaml.load(clean_stdout)['public_ips'][0].split()[0].encode())
-            setattr(options, 'minion_ip_address', yaml.load(clean_stdout)['public_ips'][0].split()[0].encode())
+            tmpip = yaml.load(clean_stdout)['public_ips']
+            if isinstance(tmpip, list):
+                setattr(options, 'minion_ip_address', yaml.load(clean_stdout)['public_ips'][0].split()[0].encode())
+            else:
+                setattr(options, 'minion_ip_address', tmpip.encode())
+
+            print('IP', options.minion_ip_address)
         except Exception as exc:
             print('Exception encountered when processing bootstrap return for display: {0}'.format(exc))
             print(clean_stdout)
@@ -929,6 +936,9 @@ def get_minion_python_executable(options):
             python_executable = 'C:\\PROGRA~1\\Python35\\python.exe'
         else:
             python_executable = 'C:\\Python27\\python.exe'
+    elif options.parallels_deploy:
+        if options.test_with_python3:
+            python_executable = '/usr/local/bin/python3'
     else:
         if options.test_with_python3:
             python_executable = '/usr/bin/python3'
@@ -1797,9 +1807,10 @@ def build_default_test_command(options):
     if options.no_color:
         test_command.append('--no-color')
     if options.windows:
-        test_command.append(
+        test_command.extend([
             '--names-file="{0}\\tests\\whitelist.txt"'
-            ''.format(options.package_source_dir))
+            ''.format(options.package_source_dir),
+            '--unit-tests'])
     test_command.append('--xml=/tmp/xml-unittests-output')
 
     if options.test_with_bash is True:
@@ -1981,6 +1992,11 @@ def get_args():
         default=False,
         help='Run the `setup.py install` step of bootstrap with `-q`'
     )
+    bootstrap_script_options.add_argument(
+        '--bootstrap-stable-install',
+        default=None,
+        help='The salt stable install to bootstrap a minion'
+    )
 
     # VM related options
     vm_options_group = parser.add_argument_group('VM Options')
